Summary: Lightweight library for embedding a webserver in applications
Name: libmicrohttpd
Version: 0.3.1
Release: 4%{?dist}
Group: Development/Libraries
Source0: ftp://ftp.gnu.org/gnu/libmicrohttpd/%{name}-%{version}.tar.gz

# This project was originally GPLv2+, but was changed later to LGPLv2+
# http://crisp.cs.du.edu/pipermail/libmicrohttpd/2007/000001.html
#
# However, the 0.3.1 release contains pieces of code from opencdk (GPLv2+)
# and openpgp (GPLv3+) which are linked in the library.
# Thus, the resulting license should be GPLv3+
#
# Upstream has removed from GPL code from the SVN repository, but
# no new release has been made yet, so for now the license is GPLv3+
# and in the next release it will be changed to LGPLv2+
License: GPLv3+

BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
URL: http://www.gnu.org/software/libmicrohttpd/

BuildRequires:	curl-devel
BuildRequires:	graphviz
BuildRequires:	doxygen

Requires(post): info
Requires(preun): info

%description
GNU libmicrohttpd is a small C library that is supposed to make it
easy to run an HTTP server as part of another application.
Key features that distinguish libmicrohttpd from other projects are:

* C library: fast and small
* API is simple, expressive and fully reentrant
* Implementation is http 1.1 compliant
* HTTP server can listen on multiple ports
* Support for IPv6
* Support for incremental processing of POST data
* Creates binary of only 25k (for now)
* Three different threading models

%package devel
Summary:	Development files for libmicrohttpd
Group:		%{group}
Requires:	%{name} = %{version}-%{release}

%description devel
Development files for libmicrohttpd

%package doc
Summary:	Documentation for libmicrohttpd
Group:		Documentation
Requires:	%{name} = %{version}-%{release}

%description doc
Doxygen documentation for libmicrohttpd and some example source code

%prep
%setup -q

# The doxygen file contains references to /home/grothoff/svn/libmicrohttpd/... replace these with .
sed s/\\/home\\/grothoff\\/svn\\/libmicrohttpd/./ doc/Doxyfile > tmp
unlink doc/Doxyfile
mv tmp doc/Doxyfile

%build
%configure --disable-static
make %{?_smp_mflags}
doxygen doc/Doxyfile

%check
make check %{?_smp_mflags}

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}

rm -f %{buildroot}%{_libdir}/libmicrohttpd.la
rm -f %{buildroot}%{_infodir}/dir

# Install some examples in /usr/share/doc/libmicrohttpd-%{version}/examples
mkdir examples
install -m 644 src/examples/*.c examples

# Install the doxygen documentation in /usr/share/doc/libmicrohttpd-${version}/html
cp -R doc/doxygen/html html

%clean
rm -rf %{buildroot}

%post doc
/sbin/install-info %{_infodir}/microhttpd.info.gz %{_infodir}/dir || :

%preun doc
if [ $1 = 0 ] ; then
/sbin/install-info --delete %{_infodir}/microhttpd.info.gz %{_infodir}/dir || :
fi

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
	
%files
%defattr(-,root,root,-)
%doc COPYING
%{_libdir}/libmicrohttpd.so.4
%{_libdir}/libmicrohttpd.so.4.0.3

%files devel
%defattr(-,root,root,-)
%{_includedir}/microhttpd.h
%{_libdir}/libmicrohttpd.so

%files doc
%defattr(-,root,root,-)
%{_mandir}/man3/libmicrohttpd.3.gz
%{_infodir}/microhttpd.info.gz
%doc AUTHORS README ChangeLog
%doc examples
%doc html

%changelog
* Fri Oct 3 2008 Erik van Pienbroek <info@nntpgrab.nl> - 0.3.1-4
* Use BR: curl-devel as Fedora 8 doesn't have libcurl-devel

* Sat Sep 6 2008 Erik van Pienbroek <info@nntpgrab.nl> - 0.3.1-3
- Changed license to GPLv3+ and added some comments
  regarding the license issues with this package

* Sun Aug 10 2008 Erik van Pienbroek <info@nntpgrab.nl> - 0.3.1-2
- Changed license to LGPLv2+
- Moved the COPYING file to the main package

* Tue Aug 5 2008 Erik van Pienbroek <info@nntpgrab.nl> - 0.3.1-1
- Initial release

